# Copyright 2021 (c) Anna Schumaker.
from lib import settings
from gi.repository import Gtk
import tagdb

class Button(Gtk.MenuButton):
    def __init__(self):
        Gtk.MenuButton.__init__(self)

        self.count   = Gtk.Label()
        self.count.set_yalign(0)
        self.count.set_markup("<small> </small>")

        self.pause   = Gtk.Image.new_from_icon_name("media-playback-start")
        self.counter = Gtk.Scale()
        self.counter.set_adjustment(tagdb.Stack.Counter)
        self.counter.connect("value-changed", self.on_counter_changed)
        self.counter.set_format_value_func(self.format_counter)
        self.counter.set_digits(0)
        self.counter.set_draw_value(True)

        settings.initialize("audio.volume", 1.0)
        self.vol_img = Gtk.Image()
        self.volume = Gtk.Scale.new_with_range(Gtk.Orientation.HORIZONTAL,
                                               0.0, 1.0, 0.05)
        self.volume.connect("value-changed", self.on_volume_changed)
        self.volume.set_value(settings.get_float("audio.volume"))
        self.volume.set_format_value_func(self.format_volume)
        self.volume.set_draw_value(True)
        self.on_volume_changed(self.volume)

        self.grid = Gtk.Grid()
        self.grid.attach(self.pause,   0, 0, 1, 1)
        self.grid.attach(self.counter, 1, 0, 1, 1)
        self.grid.attach(self.vol_img, 0, 1, 1, 1)
        self.grid.attach(self.volume,  1, 1, 1, 1)
        self.grid.add_css_class("large-icons")
        self.grid.set_column_spacing(5)

        self.popover = Gtk.Popover()
        self.popover.set_child(self.grid)

        self.overlay = Gtk.Overlay()
        self.toggle = self.get_first_child()
        self.icon = self.toggle.get_child()
        self.icon.set_margin_top(5)
        self.toggle.set_child(self.overlay)
        self.overlay.add_overlay(self.count)
        self.overlay.add_overlay(self.icon)

        self.set_popover(self.popover)
        self.add_css_class("normal-icons")

    def format_counter(self, scale, value):
        value = int(value)
        if value == -1:
            return "Keep Playing"
        elif value == 0:
            return "This Track"
        elif value == 1:
            return "Next Track"
        return f"{value} Tracks"

    def format_volume(self, scale, value):
        return f"{int(value*100)}%"

    def get_volume(self):
        return self.volume.get_value()

    def on_counter_changed(self, scale):
        value = int(scale.get_value())
        icon  = "pause" if value > -1 else "start"
        text  = " " if value == -1 else value
        self.pause.set_from_icon_name(f"media-playback-{icon}")
        self.count.set_markup(f"<small>{text}</small>")

    def on_volume_changed(self, scale):
        value = scale.get_value()
        settings.set("audio.volume", value)
        if value == 0:
            self.vol_img.set_from_icon_name("audio-volume-muted-symbolic")
        elif value < 1/3:
            self.vol_img.set_from_icon_name("audio-volume-low-symbolic")
        elif value < 2/3:
            self.vol_img.set_from_icon_name("audio-volume-medium-symbolic")
        else:
            self.vol_img.set_from_icon_name("audio-volume-high-symbolic")
