# Copyright 2021 (c) Anna Schumaker.
from . import controls
from lib import settings
from gi.repository import Gtk, Gst, GLib
import unittest

main_context = GLib.main_context_default()

class TestControls(unittest.TestCase):
    def test_controls_init(self):
        ctrl = controls.Controls()

        self.assertIsInstance(ctrl, Gtk.Box)
        self.assertIsInstance(ctrl.previous, Gtk.Button)
        self.assertIsInstance(ctrl.play, Gtk.Button)
        self.assertIsInstance(ctrl.pause, Gtk.Button)
        self.assertIsInstance(ctrl.next, Gtk.Button)
        self.assertIsInstance(ctrl.menu, Gtk.MenuButton)
        self.assertIsInstance(ctrl.sizegroup, Gtk.SizeGroup)

        self.assertEqual(ctrl.get_orientation(), Gtk.Orientation.HORIZONTAL)
        self.assertEqual(ctrl.previous.get_icon_name(), "media-skip-backward")
        self.assertEqual(ctrl.play.get_icon_name(), "media-playback-start")
        self.assertEqual(ctrl.pause.get_icon_name(), "media-playback-pause")
        self.assertEqual(ctrl.next.get_icon_name(), "media-skip-forward")

        self.assertTrue(ctrl.has_css_class("linked"))
        self.assertTrue(ctrl.has_css_class("large-icons"))
        self.assertTrue(ctrl.menu.has_css_class("normal-icons"))
        self.assertFalse(ctrl.pause.is_visible())

        self.assertIn(ctrl.previous, ctrl)
        self.assertIn(ctrl.play, ctrl)
        self.assertIn(ctrl.pause, ctrl)
        self.assertIn(ctrl.next, ctrl)
        self.assertIn(ctrl.menu, ctrl)
        self.assertIn(ctrl, ctrl.sizegroup.get_widgets())

    def test_controls_state(self):
        ctrl = controls.Controls()
        self.assertTrue(ctrl.play.is_visible())
        self.assertFalse(ctrl.pause.is_visible())

        ctrl.set_state(Gst.State.PLAYING)
        self.assertFalse(ctrl.play.is_visible())
        self.assertTrue(ctrl.pause.is_visible())

        ctrl.set_state(Gst.State.READY)
        self.assertTrue(ctrl.play.is_visible())
        self.assertFalse(ctrl.pause.is_visible())
