# Copyright 2021 (c) Anna Schumaker.
from . import seeker
from gi.repository import Gtk
import unittest

class TestSeeker(unittest.TestCase):
    def test_seeker_init(self):
        seek = seeker.Seeker()

        self.assertIsInstance(seek, Gtk.Box)
        self.assertIsInstance(seek.position, Gtk.Label)
        self.assertIsInstance(seek.remaining, Gtk.Label)
        self.assertIsInstance(seek.adjustment, Gtk.Adjustment)
        self.assertIsInstance(seek.scale, Gtk.Scale)

        self.assertEqual(seek.position.get_text(), "00:00")
        self.assertEqual(seek.remaining.get_text(), "00:00")
        self.assertEqual(seek.adjustment.get_step_increment(), 10)
        self.assertEqual(seek.scale.get_adjustment(), seek.adjustment)

        self.assertIn(seek.position, seek)
        self.assertIn(seek.scale, seek)
        self.assertIn(seek.remaining, seek)

    def test_seeker_configure(self):
        seek = seeker.Seeker()

        seek.configure(10, 100)
        self.assertEqual(seek.adjustment.get_upper(), 100)
        self.assertEqual(seek.adjustment.get_value(), 10)
        self.assertEqual(seek.position.get_text(), "00:10")
        self.assertEqual(seek.remaining.get_text(), "01:30")
        self.assertEqual(seek.get_position(), 10)

        seek.configure(65.25, 124.2)
        self.assertEqual(seek.adjustment.get_upper(), 124.2)
        self.assertEqual(seek.adjustment.get_value(), 65.25)
        self.assertEqual(seek.position.get_text(), "01:05")
        self.assertEqual(seek.remaining.get_text(), "00:58")
        self.assertEqual(seek.get_position(), 65.25)
